@@ -6,4 +6,6 @@ from list import List
 from segment import Segment
 from subscriber import Subscriber
 from campaign import Campaign
+from person import Person
+from administrator import Administrator
 import utils
