@@ -24,16 +24,17 @@ def dict_to_object(d):
 	    setattr(top, i, j)
 	return top
 
-def get_faker(expected_url, filename, status=None):
+def get_faker(expected_url, filename, status=None, body = None):
 
   class Faker(object):
     """Represents a fake web request, including the expected URL, an open 
     function which reads the expected response from a fixture file, and the
     expected response status code."""
-    def __init__(self, expected_url, filename, status):
+    def __init__(self, expected_url, filename, status, body = None):
       self.url = self.createsend_url(expected_url)
       self.filename = filename
       self.status = status
+      self.body = body
 
     def open(self):
       if self.filename:
@@ -47,4 +48,4 @@ def get_faker(expected_url, filename, status=None):
       else:
         return "http://api.createsend.com/api/v3/%s" % url
 
-  return Faker(expected_url, filename, status)
+  return Faker(expected_url, filename, status, body)
